@@ -24,7 +24,7 @@ from calculate.lib.datavars import (TableVariable, Variable, ReadonlyVariable,
 from calculate.lib.utils.files import (listDirectory, process, PIPE, pathJoin,
                                        readFileEx)
 from calculate.lib.utils.portage import (isPkgInstalled, RepositoryPath,
-                                    getInstalledAtom)
+                                    getInstalledAtom, getPortagePython)
 from calculate.lib.utils.common import cmpVersion
 from calculate.lib.datavars import DataVars
 from itertools import dropwhile
@@ -619,12 +619,14 @@ class PortageConfigWrapper(object):
 
     @classmethod
     def getconfig_chroot(cls, chroot):
+        python3 = getPortagePython(prefix=chroot)
         return cls.getconfig_python(process("/usr/bin/chroot",
-            chroot, "/usr/bin/python3"))
+            chroot, python3))
 
     @classmethod
     def getconfig(cls):
-        return cls.getconfig_python(process("/usr/bin/python3"))
+        python3 = getPortagePython()
+        return cls.getconfig_python(process(python3))
 
     @classmethod
     def getconfig_python(cls, pythonprocess):
